=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-05-09 03:17:13 +0000
+++ bzrlib/branch.py	2006-06-15 05:36:34 +0000
@@ -31,7 +31,7 @@
 from bzrlib.delta import compare_trees
 import bzrlib.errors as errors
 from bzrlib.errors import (BzrError, InvalidRevisionNumber, InvalidRevisionId,
-                           NoSuchRevision, HistoryMissing, NotBranchError,
+                           NoSuchRevision, NotBranchError,
                            DivergedBranches, LockError,
                            UninitializableFormat,
                            UnlistableStore,
@@ -300,32 +300,6 @@
         
         If self and other have not diverged, return a list of the revisions
         present in other, but missing from self.
-
-        >>> from bzrlib.workingtree import WorkingTree
-        >>> bzrlib.trace.silent = True
-        >>> d1 = bzrdir.ScratchDir()
-        >>> br1 = d1.open_branch()
-        >>> wt1 = d1.open_workingtree()
-        >>> d2 = bzrdir.ScratchDir()
-        >>> br2 = d2.open_branch()
-        >>> wt2 = d2.open_workingtree()
-        >>> br1.missing_revisions(br2)
-        []
-        >>> wt2.commit("lala!", rev_id="REVISION-ID-1")
-        >>> br1.missing_revisions(br2)
-        [u'REVISION-ID-1']
-        >>> br2.missing_revisions(br1)
-        []
-        >>> wt1.commit("lala!", rev_id="REVISION-ID-1")
-        >>> br1.missing_revisions(br2)
-        []
-        >>> wt2.commit("lala!", rev_id="REVISION-ID-2A")
-        >>> br1.missing_revisions(br2)
-        [u'REVISION-ID-2A']
-        >>> wt1.commit("lala!", rev_id="REVISION-ID-2B")
-        >>> br1.missing_revisions(br2)
-        Traceback (most recent call last):
-        DivergedBranches: These branches have diverged.  Try merge.
         """
         self_history = self.revision_history()
         self_len = len(self_history)
@@ -572,7 +546,7 @@
         except NoSuchFile:
             raise NotBranchError(path=transport.base)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     @classmethod
     def get_default_format(klass):
@@ -872,11 +846,7 @@
                  stacklevel=2)
             if (not relax_version_check
                 and not self._format.is_supported()):
-                raise errors.UnsupportedFormatError(
-                        'sorry, branch format %r not supported' % fmt,
-                        ['use a different bzr version',
-                         'or remove the .bzr directory'
-                         ' and "bzr init" again'])
+                raise errors.UnsupportedFormatError(format=fmt)
         if deprecated_passed(transport):
             warn("BzrBranch.__init__(transport=XXX...): The transport "
                  "parameter is deprecated as of bzr 0.8. "

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-06-03 16:23:09 +0000
+++ bzrlib/builtins.py	2006-06-15 05:36:34 +0000
@@ -1937,18 +1937,6 @@
         base_rev_id = common_ancestor(last1, last2, source)
 
         print 'merge base is revision %s' % base_rev_id
-        
-        return
-
-        if base_revno is None:
-            raise bzrlib.errors.UnrelatedBranches()
-
-        print ' r%-6d in %s' % (base_revno, branch)
-
-        other_revno = branch2.revision_id_to_revno(base_revid)
-        
-        print ' r%-6d in %s' % (other_revno, other)
-
 
 
 class cmd_merge(Command):

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2006-05-28 03:56:21 +0000
+++ bzrlib/bzrdir.py	2006-06-15 05:36:34 +0000
@@ -92,11 +92,7 @@
         """
         if not allow_unsupported and not format.is_supported():
             # see open_downlevel to open legacy branches.
-            raise errors.UnsupportedFormatError(
-                    'sorry, format %s not supported' % format,
-                    ['use a different bzr version',
-                     'or remove the .bzr directory'
-                     ' and "bzr init" again'])
+            raise errors.UnsupportedFormatError(format=format)
 
     def clone(self, url, revision_id=None, basis=None, force_new_repo=False):
         """Clone this bzrdir and its contents to url verbatim.
@@ -945,7 +941,7 @@
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     @classmethod
     def get_default_format(klass):

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-06-04 22:04:58 +0000
+++ bzrlib/commands.py	2006-06-15 05:36:34 +0000
@@ -34,10 +34,10 @@
 import errno
 
 import bzrlib
+import bzrlib.errors as errors
 from bzrlib.errors import (BzrError,
+                           BzrCommandError,
                            BzrCheckError,
-                           BzrCommandError,
-                           BzrOptionError,
                            NotBranchError)
 from bzrlib.option import Option
 from bzrlib.revisionspec import RevisionSpec
@@ -145,7 +145,7 @@
     if cmd_obj:
         return cmd_obj
 
-    raise BzrCommandError("unknown command %r" % cmd_name)
+    raise BzrCommandError('unknown command "%s"' % cmd_name)
 
 
 class Command(object):
@@ -233,7 +233,7 @@
         for oname in opts:
             if oname not in allowed_names:
                 raise BzrCommandError("option '--%s' is not allowed for"
-                                      " command %r" % (oname, self.name()))
+                                " command %r" % (oname, self.name()))
         # mix arguments and options into one dictionary
         cmdargs = _match_argform(self.name(), self.takes_args, args)
         cmdopts = {}
@@ -337,9 +337,7 @@
                     else:
                         optname = a[2:]
                     if optname not in cmd_options:
-                        raise BzrOptionError('unknown long option %r for'
-                                             ' command %s' % 
-                                             (a, command.name()))
+                        raise BzrCommandError('unknown option "%s"' % a)
                 else:
                     shortopt = a[1:]
                     if shortopt in Option.SHORT_OPTIONS:
@@ -354,7 +352,7 @@
                         if shortopt not in Option.SHORT_OPTIONS:
                             # We didn't find the multi-character name, and we
                             # didn't find the single char name
-                            raise BzrError('unknown short option %r' % a)
+                            raise BzrCommandError('unknown option "%s"' % a)
                         optname = Option.SHORT_OPTIONS[shortopt].name
 
                         if a[2:]:
@@ -371,15 +369,12 @@
                                 # This option takes an argument, so pack it
                                 # into the array
                                 optarg = a[2:]
-                
                     if optname not in cmd_options:
-                        raise BzrOptionError('unknown short option %r for'
-                                             ' command %s' % 
-                                             (shortopt, command.name()))
+                        raise BzrCommandError('unknown option "%s"' % shortopt)
                 if optname in opts:
                     # XXX: Do we ever want to support this, e.g. for -r?
                     if proc_aliasarg:
-                        raise BzrError('repeated option %r' % a)
+                        raise BzrCommandError('repeated option %r' % a)
                     elif optname in alias_opts:
                         # Replace what's in the alias with what's in the real
                         # argument
@@ -388,14 +383,14 @@
                         proc_argv.insert(0, a)
                         continue
                     else:
-                        raise BzrError('repeated option %r' % a)
+                        raise BzrCommandError('repeated option %r' % a)
                     
                 option_obj = cmd_options[optname]
                 optargfn = option_obj.type
                 if optargfn:
                     if optarg == None:
                         if not proc_argv:
-                            raise BzrError('option %r needs an argument' % a)
+                            raise BzrCommandError('option %r needs an argument' % a)
                         else:
                             optarg = proc_argv.pop(0)
                     opts[optname] = optargfn(optarg)
@@ -403,7 +398,7 @@
                         alias_opts[optname] = optargfn(optarg)
                 else:
                     if optarg != None:
-                        raise BzrError('option %r takes no argument' % optname)
+                        raise BzrCommandError('option %r takes no argument' % optname)
                     opts[optname] = True
                     if proc_aliasarg:
                         alias_opts[optname] = True
@@ -440,7 +435,7 @@
                 raise BzrCommandError("command %r needs one or more %s"
                         % (cmd, argname.upper()))
             argdict[argname + '_list'] = args[:-1]
-            args[:-1] = []                
+            args[:-1] = []
         else:
             # just a plain arg
             argname = ap

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2006-05-18 00:48:13 +0000
+++ bzrlib/commit.py	2006-06-15 05:36:34 +0000
@@ -81,7 +81,6 @@
 import bzrlib.config
 import bzrlib.errors as errors
 from bzrlib.errors import (BzrError, PointlessCommit,
-                           HistoryMissing,
                            ConflictsInTree,
                            StrictCommitFailed
                            )
@@ -498,9 +497,8 @@
             if not self.branch.repository.has_revision(parent_id):
                 if parent_id == self.branch.last_revision():
                     warning("parent is missing %r", parent_id)
-                    raise HistoryMissing(self.branch, 'revision', parent_id)
-                else:
-                    mutter("commit will ghost revision %r", parent_id)
+                    raise BzrCheckError("branch %s is missing revision {%s}"
+                            % (self.branch, parent_id))
             
     def _make_revision(self):
         """Record a new revision object for this commit."""

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-05-30 15:53:33 +0000
+++ bzrlib/errors.py	2006-06-15 05:36:34 +0000
@@ -16,6 +16,18 @@
 
 """Exceptions for bzr, and reporting of them.
 
+There are 3 different classes of error:
+
+ * KeyboardInterrupt, and OSError with EPIPE - the program terminates 
+   with an appropriate short message
+
+ * User errors, indicating a problem caused by the user such as a bad URL.
+   These are printed in a short form.
+ 
+ * Internal unexpected errors, including most Python builtin errors
+   and some raised from inside bzr.  These are printed with a full 
+   traceback and an invitation to report the bug.
+
 Exceptions are caught at a high level to report errors to the user, and
 might also be caught inside the program.  Therefore it needs to be
 possible to convert them to a meaningful string, and also for them to be
@@ -44,13 +56,14 @@
 Therefore:
 
  * create a new exception class for any class of error that can be
-   usefully distinguished.
-
- * the printable form of an exception is generated by the base class
-   __str__ method
-
-Exception strings should start with a capital letter and not have a final
-fullstop.
+   usefully distinguished.  If no callers are likely to want to catch
+   one but not another, don't worry about them.
+
+ * the __str__ method should generate something useful; BzrError provides
+   a good default implementation
+
+Exception strings should start with a capital letter and should not have a
+final fullstop.
 """
 
 from warnings import warn
@@ -81,6 +94,9 @@
 
 
 class BzrError(StandardError):
+    
+    is_user_error = True
+    
     def __str__(self):
         # XXX: Should we show the exception class in 
         # exceptions that don't provide their own message?  
@@ -119,6 +135,8 @@
 class BzrCheckError(BzrNewError):
     """Internal check failed: %(message)s"""
 
+    is_user_error = False
+
     def __init__(self, message):
         BzrNewError.__init__(self)
         self.message = message
@@ -126,6 +144,9 @@
 
 class InvalidEntryName(BzrNewError):
     """Invalid entry name: %(name)s"""
+
+    is_user_error = False
+
     def __init__(self, name):
         BzrNewError.__init__(self)
         self.name = name
@@ -163,7 +184,9 @@
         self.url = url
 
 
-class BzrCommandError(BzrError):
+class BzrCommandError(BzrNewError):
+    """Error from user command"""
+    is_user_error = True
     # Error from malformed user command
     # This is being misused as a generic exception
     # pleae subclass. RBC 20051030
@@ -172,15 +195,14 @@
     # are not intended to be caught anyway.  UI code need not subclass
     # BzrCommandError, and non-UI code should not throw a subclass of
     # BzrCommandError.  ADHB 20051211
+    def __init__(self, msg):
+        self.msg = msg
+
     def __str__(self):
-        return self.args[0]
-
-
-class BzrOptionError(BzrCommandError):
-    """Some missing or otherwise incorrect option was supplied."""
-
-    
-class StrictCommitFailed(Exception):
+        return self.msg
+
+
+class StrictCommitFailed(BzrNewError):
     """Commit refused because there are unknowns in the tree."""
 
 
@@ -199,27 +221,30 @@
 
 
 class NoSuchFile(PathError):
-    """No such file: %(path)r%(extra)s"""
+    """No such file: %(path)s%(extra)s"""
 
 
 class FileExists(PathError):
-    """File exists: %(path)r%(extra)s"""
+    """File exists: %(path)s%(extra)s"""
 
 
 class DirectoryNotEmpty(PathError):
-    """Directory not empty: %(path)r%(extra)s"""
+    """Directory not empty: %(path)s%(extra)s"""
 
 
 class ResourceBusy(PathError):
-    """Device or resource busy: %(path)r%(extra)s"""
+    """Device or resource busy: %(path)s%(extra)s"""
 
 
 class PermissionDenied(PathError):
-    """Permission denied: %(path)r%(extra)s"""
+    """Permission denied: %(path)s%(extra)s"""
 
 
 class PathNotChild(BzrNewError):
-    """Path %(path)r is not a child of path %(base)r%(extra)s"""
+    """Path %(path)s is not a child of path %(base)s%(extra)s"""
+
+    is_user_error = False
+
     def __init__(self, path, base, extra=None):
         BzrNewError.__init__(self)
         self.path = path
@@ -244,7 +269,7 @@
 
 
 class NoRepositoryPresent(BzrNewError):
-    """No repository present: %(path)r"""
+    """No repository present: %(path)s"""
     def __init__(self, bzrdir):
         BzrNewError.__init__(self)
         self.path = bzrdir.transport.clone('..').base
@@ -260,16 +285,12 @@
         self.path = path
 
 
-class UnsupportedFormatError(BzrError):
-    """Specified path is a bzr branch that we recognize but cannot read."""
-    def __str__(self):
-        return 'unsupported branch format: %s' % self.args[0]
-
-
-class UnknownFormatError(BzrError):
-    """Specified path is a bzr branch whose format we do not recognize."""
-    def __str__(self):
-        return 'unknown branch format: %s' % self.args[0]
+class UnsupportedFormatError(BzrNewError):
+    """Unsupported branch format: %(format)s"""
+
+
+class UnknownFormatError(BzrNewError):
+    """Unknown branch format: %(format)s"""
 
 
 class IncompatibleFormat(BzrNewError):
@@ -357,7 +378,8 @@
 
 
 class ObjectNotLocked(LockError):
-    """%(obj)r is not locked"""
+    """%(obj)s is not locked"""
+    is_user_error = False
     # this can indicate that any particular object is not locked; see also
     # LockNotHeld which means that a particular *lock* object is not held by
     # the caller -- perhaps they should be unified.
@@ -366,7 +388,7 @@
 
 
 class ReadOnlyObjectDirtiedError(ReadOnlyError):
-    """Cannot change object %(obj)r in read only transaction"""
+    """Cannot change object %(obj)s in read only transaction"""
     def __init__(self, obj):
         self.obj = obj
 
@@ -391,7 +413,7 @@
 
 
 class LockBreakMismatch(LockError):
-    """Lock was released and re-acquired before being broken: %(lock)s: held by %(holder)r, wanted to break %(target)r"""
+    """Lock was released and re-acquired before being broken: %(lock)s: held by %(holder)s, wanted to break %(target)r"""
     def __init__(self, lock, holder, target):
         self.lock = lock
         self.holder = holder
@@ -425,42 +447,38 @@
     """Commit refused because there are unknowns in the tree."""
 
 
-class NoSuchRevision(BzrError):
+class NoSuchRevision(BzrNewError):
+    """Branch %(branch)s has no revision %(revision)s"""
+
+    is_user_error = False
+
     def __init__(self, branch, revision):
         self.branch = branch
         self.revision = revision
-        msg = "Branch %s has no revision %s" % (branch, revision)
-        BzrError.__init__(self, msg)
-
-
-class HistoryMissing(BzrError):
-    def __init__(self, branch, object_type, object_id):
-        self.branch = branch
-        BzrError.__init__(self,
-                          '%s is missing %s {%s}'
-                          % (branch, object_type, object_id))
-
-
-class DivergedBranches(BzrError):
+
+
+class DivergedBranches(BzrNewError):
+    "These branches have diverged.  Use the merge command to reconcile them."""
+
+    is_user_error = True
 
     def __init__(self, branch1, branch2):
-        BzrError.__init__(self, "These branches have diverged.  Try merge.")
         self.branch1 = branch1
         self.branch2 = branch2
 
 
-class UnrelatedBranches(BzrCommandError):
-    def __init__(self):
-        msg = "Branches have no common ancestor, and no base revision"\
-            " specified."
-        BzrCommandError.__init__(self, msg)
-
-
-class NoCommonAncestor(BzrError):
+class UnrelatedBranches(BzrNewError):
+    "Branches have no common ancestor, and no merge base revision was specified."
+
+    is_user_error = True
+
+
+class NoCommonAncestor(BzrNewError):
+    "Revisions have no common ancestor: %(revision_a)s %(revision_b)s"
+
     def __init__(self, revision_a, revision_b):
-        msg = "Revisions have no common ancestor: %s %s." \
-            % (revision_a, revision_b) 
-        BzrError.__init__(self, msg)
+        self.revision_a = revision_a
+        self.revision_b = revision_b
 
 
 class NoCommonRoot(BzrError):

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-05-25 17:20:51 +0000
+++ bzrlib/repository.py	2006-06-15 05:36:34 +0000
@@ -867,7 +867,7 @@
         except errors.NoSuchFile:
             raise errors.NoRepositoryPresent(a_bzrdir)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     def _get_control_store(self, repo_transport, control_files):
         """Return the control store for this repository."""

=== modified file 'bzrlib/tests/blackbox/test_aliases.py'
--- bzrlib/tests/blackbox/test_aliases.py	2006-03-12 20:42:58 +0000
+++ bzrlib/tests/blackbox/test_aliases.py	2006-06-15 05:36:34 +0000
@@ -57,9 +57,9 @@
 
         # If --no-aliases breaks all of bzr, we also get retcode=3
         # So we need to catch the output as well
-        self.assertEquals(bzr_catch_error('--no-aliases', 'c', 'a', 
-                                          retcode=None), 
-                          "bzr: ERROR: unknown command 'c'\n")
+        self.assertEquals(bzr_catch_error('--no-aliases', 'c', 'a',
+                                          retcode=None),
+                          'bzr: ERROR: unknown command "c"\n')
 
         bzr('c', '-r1', '-r2', retcode=3)
         bzr('c1', '-r1', '-r2', retcode=3)

=== modified file 'bzrlib/tests/blackbox/test_exceptions.py'
--- bzrlib/tests/blackbox/test_exceptions.py	2006-06-04 22:04:20 +0000
+++ bzrlib/tests/blackbox/test_exceptions.py	2006-06-15 05:36:34 +0000
@@ -20,7 +20,7 @@
 import sys
 
 from bzrlib.tests import TestCaseInTempDir, TestCase
-from bzrlib.errors import NotBranchError, BzrError, BzrNewError
+from bzrlib.errors import NotBranchError
 
 class TestExceptionReporting(TestCase):
 

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2006-06-04 22:04:20 +0000
+++ bzrlib/tests/blackbox/test_init.py	2006-06-15 05:36:34 +0000
@@ -71,7 +71,7 @@
         out, err = self.run_bzr('init', 'subdir2/nothere', retcode=3)
         self.assertEqual('', out)
         self.assertContainsRe(err,
-            r'^bzr: ERROR: exceptions.OSError: '
+            r'^bzr: ERROR: .*'
             '\[Errno 2\] No such file or directory: ')
         
         os.mkdir('subdir2')

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2006-04-19 05:22:38 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2006-06-15 05:36:34 +0000
@@ -248,7 +248,7 @@
         tree_b.commit('commit d')
         out = self.runbzr('pull ../branch_a', retcode=3)
         self.assertEquals(out,
-                ('','bzr: ERROR: These branches have diverged.  Try merge.\n'))
+                ('','bzr: ERROR: These branches have diverged.  Use the merge command to reconcile them.\n'))
         self.assertEquals(abspath(branch_b.get_parent()), abspath(parent))
         # test implicit --remember after resolving previous failure
         uncommit(branch=branch_b, tree=tree_b)

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2006-02-26 07:54:02 +0000
+++ bzrlib/tests/test_errors.py	2006-06-15 05:36:34 +0000
@@ -27,8 +27,8 @@
     def test_no_repo(self):
         dir = bzrdir.BzrDir.create(self.get_url())
         error = errors.NoRepositoryPresent(dir)
-        self.assertNotEqual(-1, str(error).find(repr(dir.transport.clone('..').base)))
-        self.assertEqual(-1, str(error).find(repr(dir.transport.base)))
+        self.assertNotEqual(-1, str(error).find((dir.transport.clone('..').base)))
+        self.assertEqual(-1, str(error).find((dir.transport.base)))
 
     def test_up_to_date(self):
         error = errors.UpToDateFormat(bzrdir.BzrDirFormat4())

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2006-03-22 17:48:49 +0000
+++ bzrlib/tests/test_options.py	2006-06-15 05:36:34 +0000
@@ -46,7 +46,7 @@
 
     def test_unknown_short_opt(self):
         out, err = self.run_bzr_captured(['help', '-r'], retcode=3)
-        self.assertContainsRe(err, r'unknown short option')
+        self.assertContainsRe(err, r'unknown option')
 
 
 #     >>> parse_args('log -r 500'.split())

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2006-03-05 02:20:07 +0000
+++ bzrlib/tests/test_source.py	2006-06-15 05:36:34 +0000
@@ -72,4 +72,4 @@
         # written. Note that this is an exact equality so that when the number
         # drops, it is not given a buffer but rather this test updated
         # immediately.
-        self.assertEqual(4, occurences)
+        self.assertEqual(3, occurences)

=== modified file 'bzrlib/tests/test_trace.py'
--- bzrlib/tests/test_trace.py	2006-06-04 22:13:03 +0000
+++ bzrlib/tests/test_trace.py	2006-06-15 05:36:34 +0000
@@ -26,7 +26,7 @@
 
 from bzrlib.tests import TestCaseInTempDir, TestCase
 from bzrlib.trace import mutter, report_exception
-from bzrlib.errors import NotBranchError, BzrError, BzrNewError
+from bzrlib.errors import NotBranchError
 
 
 def _format_exception():
@@ -78,17 +78,6 @@
         self.assertTrue(len(msg) > 0)
         self.assertEqualDiff(msg, 'bzr: ERROR: Not a branch: wibble\n')
 
-    def test_format_old_exception(self):
-        # format a class that doesn't descend from BzrNewError; 
-        # remove this test when everything is unified there
-        self.assertFalse(issubclass(BzrError, BzrNewError))
-        try:
-            raise BzrError('some old error')
-        except BzrError:
-            pass
-        msg = _format_exception()
-        self.assertEqualDiff(msg, 'bzr: ERROR: some old error\n')
-
     def test_trace_unicode(self):
         """Write Unicode to trace log"""
         self.log(u'the unicode character for benzene is \N{BENZENE RING}')

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2006-06-04 22:13:03 +0000
+++ bzrlib/trace.py	2006-06-15 05:36:34 +0000
@@ -234,7 +234,11 @@
         print >>err_file, "bzr: broken pipe"
     elif isinstance(exc_object, KeyboardInterrupt):
         print >>err_file, "bzr: interrupted"
-    elif isinstance(exc_info[1], (IOError, OSError, BzrError, BzrNewError)):
+    elif getattr(exc_object, 'is_user_error', False):
+        report_user_error(exc_info, err_file)
+    elif isinstance(exc_object, (OSError, IOError)):
+        # Might be nice to catch all of these and show them as something more
+        # specific, but there are too many cases at the moment.
         report_user_error(exc_info, err_file)
     else:
         report_bug(exc_info, err_file)
@@ -253,11 +257,10 @@
     print >>err_file
     traceback.print_exception(exc_type, exc_object, exc_tb, file=err_file)
     print >>err_file
-    print >>err_file, 'bzr %s invoked on python %s (%s)' % \
+    print >>err_file, 'bzr %s on python %s (%s)' % \
                        (bzrlib.__version__,
                         '.'.join(map(str, sys.version_info)),
                         sys.platform)
-    print >>err_file, '  arguments: %r' % sys.argv
+    print >>err_file, 'arguments: %r' % sys.argv
     print >>err_file
     print >>err_file, "** please send this report to bazaar-ng@lists.ubuntu.com"
-    print >>err_file, "   with a description of how and when the problem occurred"

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-05-27 09:24:05 +0000
+++ bzrlib/workingtree.py	2006-06-15 05:36:34 +0000
@@ -60,7 +60,6 @@
 from bzrlib.errors import (BzrCheckError,
                            BzrError,
                            ConflictFormatError,
-                           DivergedBranches,
                            WeaveRevisionNotPresent,
                            NotBranchError,
                            NoSuchFile,
@@ -1554,7 +1553,7 @@
         except NoSuchFile:
             raise errors.NoWorkingTree(base=transport.base)
         except KeyError:
-            raise errors.UnknownFormatError(format_string)
+            raise errors.UnknownFormatError(format=format_string)
 
     @classmethod
     def get_default_format(klass):

